@@ -152,6 +152,10 @@ def test_ordinal():
     assert p.ordinal(103) == "103rd"
     assert p.ordinal(104) == "104th"
 
+    assert p.ordinal(1.1) == "1.1st"
+    assert p.ordinal(1.2) == "1.2nd"
+    assert p.ordinal(5.502) == "5.502nd"
+
     assert p.ordinal("zero") == "zeroth"
     assert p.ordinal("one") == "first"
     assert p.ordinal("two") == "second"
@@ -184,6 +188,19 @@ def test_ordinal():
     assert p.ordinal("one hundred and four") == "one hundred and fourth"
 
 
+def test_decimal_ordinals():
+    """
+    Capture expectation around ordinals for decimals.
+
+    This expectation is held loosely. Another expectation may be
+    considered if appropriate.
+    """
+
+    p = inflect.engine()
+    assert p.ordinal("1.23") == "1.23rd"
+    assert p.ordinal("7.09") == "7.09th"
+
+
 def test_prespart():
     p = inflect.engine()
     assert p.present_participle("sees") == "seeing"
